laueagle
=============================

Introduction
------------

A data serialization format tools

Documentation
-------------

See `docs/`

Development
-----------

Run `make` to see a list of available options.

Authors
-------

* Liqiang Lau <liqianglau@outlook.com>

License
-------

MIT
